@@ -79,7 +79,7 @@ def get_ASTROMER(num_layers=2,
 
         # Loading the model
         if os.path.isdir(model_path):
-            model = model.load_weights(model_path)
+            model = model.load_weights(destinationpath)
 
     else:
         serie  = Input(shape=(maxlen, 1),
